from PyObjCTools.TestSupport import TestCase
import SharedWithYouCore  # noqa: F401


class TestSWCollaborationActionHandler(TestCase):
    def test_protocols(self):
        self.assertProtocolExists("SWCollaborationActionHandler")



from PyObjCTools.TestSupport import TestCase
import SharedWithYouCore


class TestSWAction(TestCase):
    def test_constants(self):
        self.assertIsTypedEnum(SharedWithYouCore.SWCollaborationIdentifier, str)
        self.assertIsTypedEnum(SharedWithYouCore.SWLocalCollaborationIdentifier, str)



from PyObjCTools.TestSupport import TestCase
import SharedWithYouCore


class TestSWCollaborationOption(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(SharedWithYouCore.SWCollaborationOption.isSelected)



from PyObjCTools.TestSupport import TestCase
import SharedWithYouCore


class TestSWCollaborationOptionsGroup(TestCase):
    def test_constants(self):
        self.assertIsInstance(
            SharedWithYouCore.UTCollaborationOptionsTypeIdentifier, str
        )



from PyObjCTools.TestSupport import TestCase
import SharedWithYouCore


class TestSWAction(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(SharedWithYouCore.SWAction.isComplete)



from PyObjCTools.TestSupport import TestCase
import SharedWithYouCore


class TestSharedWithYouCore(TestCase):
    def test_constants(self):
        self.assertIsInstance(SharedWithYouCore.SharedWithYouCoreVersionNumber, float)
        self.assertNotHasAttr(SharedWithYouCore, "SharedWithYouCoreVersionString")

    def test_metadata_sane(self):
        self.assertCallableMetadataIsSane(SharedWithYouCore)



# This file is generated by objective.metadata
#
# Last update: Fri Aug 12 15:20:56 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = (
    """$SharedWithYouCoreVersionNumber@d$UTCollaborationOptionsTypeIdentifier$"""
)
enums = """$$"""
misc.update({})
misc.update(
    {
        "SWCollaborationIdentifier": NewType("SWCollaborationIdentifier", str),
        "SWLocalCollaborationIdentifier": NewType(
            "SWLocalCollaborationIdentifier", str
        ),
    }
)
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSObject",
        b"collaborationCoordinator:handleStartCollaborationAction:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"collaborationCoordinator:handleUpdateCollaborationParticipantsAction:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(b"SWAction", b"isComplete", {"retval": {"type": b"Z"}})
    r(b"SWCollaborationOption", b"isSelected", {"retval": {"type": b"Z"}})
    r(b"SWCollaborationOption", b"setSelected:", {"arguments": {2: {"type": b"Z"}}})
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



"""
Python mapping for the SharedWithYouCore framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import AppKit
import objc
from SharedWithYouCore import _metadata
import SharedWithYouCore._SharedWithYouCore

sys.modules["SharedWithYouCore"] = mod = objc.ObjCLazyModule(
    "SharedWithYouCore",
    "com.apple.SharedWithYouCore",
    objc.pathForFramework("/System/Library/Frameworks/SharedWithYouCore.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,  # noqa: F405
        "__loader__": globals().get("__loader__", None),
    },
    (SharedWithYouCore._SharedWithYouCore, AppKit),
)

del sys.modules["SharedWithYouCore._metadata"]
